<?php
/**
 {{COPYRIGHT_NOTICE}}
 */

/**
 * @inheritdoc
 */
class Montonio_Gateway_Block_Payments_Adminhtml_Source_AvailableMethods extends Mage_Adminhtml_Block_System_Config_Form_Field_Array_Abstract
{
    /**
     * @inheritdoc
     */
    public function __construct()
    {
        $this->addColumn('method_enabled', [
            'label' => Mage::helper('montonio')->__('On/Off'),
            'style' => 'width: 50px'
        ]);

        $this->addColumn('method_title', [
            'label' => Mage::helper('montonio')->__('Title'),
            'style' => 'width: 150px'
        ]);

        $this->addColumn('method_desc', [
            'label' => Mage::helper('montonio')->__('Description'),
            'style' => 'width: 150px'
        ]);

        $this->addColumn('logo_url', [
            'label' => Mage::helper('montonio')->__('Logo Url'),
            'style' => 'width: 150px'
        ]);

        $this->_addAfter = false;
        $this->_addButtonLabel = Mage::helper('montonio')->__('Add label');

        parent::__construct();

        $this->setTemplate('montonio/array.phtml');
    }

    /**
     * @inheritdoc
     */
    protected function _renderCellTemplate($columnName)
    {
        if ($columnName != 'method_enabled') {
            return parent::_renderCellTemplate($columnName);
        }

        if (empty($this->_columns[$columnName])) {
            throw new Exception('Wrong column name specified.');
        }

        $column = $this->_columns[$columnName];
        $inputName = $this->getElement()->getName() . '[#{_id}][' . $columnName . ']';

        if ($column['renderer']) {
            return $column['renderer']->setInputName($inputName)
                ->setColumnName($columnName)
                ->setColumn($column)
                ->toHtml();
        }

        $options = [
            '0' => Mage::helper('montonio')->__('Off'),
            '1' => Mage::helper('montonio')->__('On')
        ];
        $optionsHtml = '';
        foreach ($options as $k => $v) {
            $optionsHtml .= '<option value="' . $k . '">' . $v  . '</option>';
        }
        $styleHtml = (isset($column['style']) ? ' style="' . $column['style'] . '"' : '');
        $cssHtml = (isset($column['class']) ? $column['class'] : 'input-select');
        $selectHtml = '<select data-selected-value="#{method_enabled}" name="' . $inputName . '" class="' . $cssHtml . '"' . $styleHtml . '>' . $optionsHtml . '</select>';

        return $selectHtml;
    }

    /**
     * @inheritdoc
     */
    protected function _prepareArrayRow(Varien_Object $row)
    {
    }

    /**
     * @inheritdoc
     */
    public function getArrayRows()
    {
        $values = $this->getElement()->getValue();

        if (!is_array($values)) {
            $values = [];
        }
        try {
            $methods = Mage::getModel('montonio/method_payments')->aspspsCommand();
            foreach ($methods as $k => $v) {
                if (!isset($values[$v['bic']])) {
                    $values[$v['bic']] = [
                        'method_enabled'=> '1',
                        'method_title'=> $v['name'],
                        'method_desc' => $v['name'],
                        'logo_url'    => $v['logo_url']
                    ];
                }
            }
        } catch (\Exception $e) {
            //silence
            $this->silence();
        }

        $this->getElement()->setValue($values);

        return parent::getArrayRows();
    }

    /**
     * Do nothing
     * @return void
     */
    public function silence()
    {
    }
}
